# groupy

### Description

Python client library for interfacing with the Grouper API server.

### Installation

New versions will be updated to PyPI pretty regularly so it should be as easy
as:

```bash
pip install groupy
```
